@@ -20,6 +20,17 @@ def timestamp():
     return str(date_time)
 
 
+def pickle(filepath, object_to_pickle):
+	"""
+	Pickles object_to_pickle saved at 
+	filepath. filepath is a 'str' and
+	should end in '.pkl'.  
+	"""
+	out_file = open(filepath, "wb")
+	pickle.dump(object_to_pickle, out_file)
+	out_file.close()
+
+
 def unpickle(filepath):
 	"""
 	Takes in a path to a pickled 
